using System;
using Server.Items;

namespace Server.Engines.Craft
{
	public class DefBlacksmithy : CraftSystem
	{
		public override SkillName MainSkill
		{
			get	{ return SkillName.Blacksmith;	}
		}

		public override string GumpTitle
		{
			get { return "BLACKSMITHY MENU"; }
		}

		public override int GumpTitlePos
		{
			get { return 160; }
		}

		private static CraftSystem m_CraftSystem;

		public static CraftSystem CraftSystem
		{
			get
			{
				if ( m_CraftSystem == null )
					m_CraftSystem = new DefBlacksmithy();

				return m_CraftSystem;
			}
		}

		private DefBlacksmithy() : base( 1, 2, 1.7 )
		{
			/*
			
			base( MinCraftEffect, MaxCraftEffect, Delay )
			
			MinCraftEffect	: The minimum number of time the mobile will play the craft effect
			MaxCraftEffect	: The maximum number of time the mobile will play the craft effect
			Delay			: The delay between each craft effect
			
			Example: (3, 6, 1.7) would make the mobile do the PlayCraftEffect override
			function between 3 and 6 time, with a 1.7 second delay each time.
			
			*/ 
		}

		public override bool CanCraft( Mobile from, BaseTool tool, Type itemType )
		{
			if ( tool.Deleted )
			{
				return false;
			}
			else
			{
				if ( tool.Durability < 1 )
				{
					from.SendMessage( "This tool is broken" );
					return false;
				}
			}
			
			// Check if we are near an Anvil and a Forge

			bool anvil = false, forge = false;

			IPooledEnumerable inRange = from.Map.GetItemsInRange( from.Location, 2 );

			foreach ( Item item in inRange )
			{
				if ( item.GetType().IsDefined( typeof( AnvilAttribute ), false ) )
					anvil = true;

				if ( item.GetType().IsDefined( typeof( ForgeAttribute ), false ) )
					forge = true;

				if ( anvil && forge )
				{
					inRange.Free();
					return true;
				}
			}

			inRange.Free();

			from.SendLocalizedMessage( 1044267 ); // You must be near an anvil and a forge to smith items

			return false;
		}

		public override void PlayCraftEffect( Mobile from )
		{
			if ( from.Body.Type == BodyType.Human && !from.Mounted )
				from.Animate( 9, 5, 1, true, false, 0 );

			new InternalTimer( from ).Start();
		}

		// Delay to synchronize the sound with the hit on the anvil
		private class InternalTimer : Timer
		{
			private Mobile m_From;

			public InternalTimer( Mobile from ) : base( TimeSpan.FromSeconds( 0.7 ) )
			{
				m_From = from;
			}

			protected override void OnTick()
			{
				m_From.PlaySound( 0x2A );
			}
		}

		public override void PlayEndingEffect( Mobile from, bool failed, bool lostMaterial, bool toolBroken, int quality )
		{
			if ( toolBroken )
			{
				from.SendLocalizedMessage( 1044038 ); // You have worn out your tool
			}

			if ( failed )
			{
				if ( lostMaterial) 
				{
					from.SendLocalizedMessage( 1044043 ); // You failed to create the item, and some of your materials are lost.
				}
				else
				{
					from.SendLocalizedMessage( 1044157 ); // You failed to create the item, but no materials were lost.
				}
			}
			else
			{
				if ( quality == 0 )
					from.SendLocalizedMessage( 502785 ); // You were barely able to make the item.  It's quality is below average
				else if (quality == 2 )
					from.SendLocalizedMessage( 502784 ); // Due to your exceptional skill, its quality is higher than average
				else				
					from.SendLocalizedMessage( 1044154 ); // You create the item
			}
		}

		public override void InitCraftList()
		{
			/*
			Synthax for a SIMPLE craft item
			AddCraft( ObjectType, Group, MinSkill, MaxSkill, RessourceType, Amount, Message )
			
			ObjectType		: The type of the object you want to add to the build list.
			Group			: The group in wich the object will be showed in the craft menu.
			MinSkill		: The minimum of skill value
			MaxSkill		: The maximum of skill value
			RessourceType	: The type of the ressource the mobile need to create the item
			Amount			: The amount of the RessourceType it need to create the item
			Message			: String or Int for Localized.  The message that will be sent to the mobile, if the specified ressource is missing.
			
			Synthax for a COMPLEXE craft item.  A complexe item is an item that need either more than
			only one skill, or more than only one ressource.
			
			Coming soon....
			*/

			// Ringmail
			AddCraft( typeof( RingmailGloves ), "Ringmail", "Ringmail Gloves", 12.0, 24.0, typeof( IronIngot ), "Iron Ingot", 10, 1044037 );
			AddCraft( typeof( RingmailArms ), "Ringmail", "Ringmail Sleeves", 16.9, 32.0, typeof( IronIngot ), "Iron Ingot", 14, 1044037 );
			AddCraft( typeof( RingmailLegs ), "Ringmail", "Ringmail Leggings", 19.4, 40.0, typeof( IronIngot ), "Iron Ingot", 16, 1044037 );
			AddCraft( typeof( RingmailChest ), "Ringmail", "Ringmail Tunic", 21.9, 42.0, typeof( IronIngot ), "Iron Ingot", 18, 1044037 );

			// Chainmail
			AddCraft( typeof( ChainLegs ), "Chainmail", "Chainmail Leggings", 36.7, 70.0, typeof( IronIngot ), "Iron Ingot", 18, 1044037 );
			AddCraft( typeof( ChainChest ), "Chainmail", "Chainmail Tunic", 39.1, 80.0, typeof( IronIngot ), "Iron Ingot", 20, 1044037 );

			// Platemail
			AddCraft( typeof( PlateGorget ), "Platemail", "Platemail Gorget", 56.4, 95.0, typeof( IronIngot ), "Iron Ingot", 10, 1044037 );
			AddCraft( typeof( PlateGloves ), "Platemail", "Platemail Gloves", 58.9, 100.0, typeof( IronIngot ), "Iron Ingot", 12, 1044037 );
			AddCraft( typeof( PlateArms ), "Platemail", "Platemail Arms", 66.3, 100.0, typeof( IronIngot ), "Iron Ingot", 18, 1044037 );
			AddCraft( typeof( PlateLegs ), "Platemail", "Platemail Leggings", 68.8, 100.0, typeof( IronIngot ), "Iron Ingot", 20, 1044037 );
			AddCraft( typeof( PlateChest ), "Platemail", "Platemail Tunic", 75.0, 100.0, typeof( IronIngot ), "Iron Ingot", 25, 1044037 );
			AddCraft( typeof( FemalePlateChest ), "Platemail", "Platemail Tunic (female)", 44.1, 85.0, typeof( IronIngot ), "Iron Ingot", 20, 1044037 );

			// Helmets
			AddCraft( typeof( ChainCoif ), "Helmets", "Chainmail Coif", 14.5, 30.0, typeof( IronIngot ), "Iron Ingot", 10, 1044037 );
			AddCraft( typeof( Helmet ), "Helmets", "Helmet", 37.9, 80.0, typeof( IronIngot ), "Iron Ingot", 15, 1044037 );
			AddCraft( typeof( Bascinet ), "Helmets", "Bascinet", 38.3, 80.0, typeof( IronIngot ), "Iron Ingot", 15, 1044037 );
			AddCraft( typeof( NorseHelm ), "Helmets", "Nose Helm", 37.9, 80.0, typeof( IronIngot ), "Iron Ingot", 15, 1044037 );
			AddCraft( typeof( CloseHelm ), "Helmets", "Close Helm", 37.9, 80.0, typeof( IronIngot ), "Iron Ingot", 15, 1044037 );
			AddCraft( typeof( PlateHelm ), "Helmets", "Plate Helm", 62.6, 100.0, typeof( IronIngot ), "Iron Ingot", 15, 1044037 );
			
			// Bladed
			AddCraft( typeof( Dagger ), "Bladed", "Dagger", 0.0, 20.0, typeof( IronIngot ), "Iron Ingot", 3, 1044037 );
			AddCraft( typeof( Cutlass ), "Bladed", "Cutlass", 24.3, 50.0, typeof( IronIngot ), "Iron Ingot", 8, 1044037 );
			AddCraft( typeof( Katana ), "Bladed", "Katana", 44.1, 90.0, typeof( IronIngot ), "Iron Ingot", 8, 1044037 );
			AddCraft( typeof( Kryss ), "Bladed", "Kryss", 36.7, 70.0, typeof( IronIngot ), "Iron Ingot", 8, 1044037 );
			AddCraft( typeof( Scimitar ), "Bladed", "Scimitar", 31.7, 60.0, typeof( IronIngot ), "Iron Ingot", 10, 1044037 );
			AddCraft( typeof( Broadsword ), "Bladed", "Broadsword", 35.4, 70.0, typeof( IronIngot ), "Iron Ingot", 10, 1044037 );
			AddCraft( typeof( Longsword ), "Bladed", "Longsword", 28.0, 50.0, typeof( IronIngot ), "Iron Ingot", 12, 1044037 );
			AddCraft( typeof( VikingSword ), "Bladed", "Viking Sword", 24.3, 50.0, typeof( IronIngot ), "Iron Ingot", 14, 1044037 );
			
			// Axes
			AddCraft( typeof( BattleAxe ), "Axes", "Battle Axe", 30.5, 60.0, typeof( IronIngot ), "Iron Ingot", 14, 1044037 );
			AddCraft( typeof( Axe ), "Axes", "Axe", 34.2, 70.0, typeof( IronIngot ), "Iron Ingot", 14, 1044037 );
			AddCraft( typeof( ExecutionersAxe ), "Axes", "Executioners Axe", 34.2, 70.0, typeof( IronIngot ), "Iron Ingot", 14, 1044037 );
			AddCraft( typeof( TwoHandedAxe ), "Axes", "Two-handed Axe", 33.0, 70.0, typeof( IronIngot ), "Iron Ingot", 16, 1044037 );
			AddCraft( typeof( DoubleAxe ), "Axes", "Double Axe", 29.3, 60.0, typeof( IronIngot ), "Iron Ingot", 12, 1044037 );
			AddCraft( typeof( LargeBattleAxe ), "Axes", "Large Battle Axe", 28.0, 55.0, typeof( IronIngot ), "Iron Ingot", 12, 1044037 );
			AddCraft( typeof( WarAxe ), "Axes", "War Axe", 39.1, 80.0, typeof( IronIngot ), "Iron Ingot", 16, 1044037 );

			// Pole Arms
			AddCraft( typeof( ShortSpear ), "Pole Arms", "Short Spear", 45.3, 90.0, typeof( IronIngot ), "Iron Ingot", 6, 1044037 );
			AddCraft( typeof( Spear ), "Pole Arms", "Spear", 49.0, 95.0, typeof( IronIngot ), "Iron Ingot", 12, 1044037 );
			AddCraft( typeof( Pitchfork ), "Pole Arms", "Pitchfork", 36.1, 70.0, typeof( IronIngot ), "Iron Ingot", 12, 1044037 );
			AddCraft( typeof( WarFork ), "Pole Arms", "War Fork", 42.9, 85.0, typeof( IronIngot ), "Iron Ingot", 12, 1044037 );
			AddCraft( typeof( Bardiche ), "Pole Arms", "Bardiche", 31.7, 62.0, typeof( IronIngot ), "Iron Ingot", 18, 1044037 );
			AddCraft( typeof( Halberd ), "Pole Arms", "Halberd", 39.1, 80.0, typeof( IronIngot ), "Iron Ingot", 20, 1044037 );

			// Maces
			AddCraft( typeof( Mace ), "Maces", "Mace", 14.5, 30.0, typeof( IronIngot ), "Iron Ingot", 6, 1044037 );
			AddCraft( typeof( Maul ), "Maces", "Maul", 19.4, 40.0, typeof( IronIngot ), "Iron Ingot", 10, 1044037 );
			AddCraft( typeof( WarMace ), "Maces", "War Mace", 28.0, 56.0, typeof( IronIngot ), "Iron Ingot", 14, 1044037 );
			AddCraft( typeof( WarHammer ), "Maces", "War Hammer", 34.2, 70.0, typeof( IronIngot ), "Iron Ingot", 16, 1044037 );
			AddCraft( typeof( HammerPick ), "Maces", "Hammer Pick", 34.2, 70.0, typeof( IronIngot ), "Iron Ingot", 16, 1044037 );

			// Shields
			AddCraft( typeof( Buckler ), "Shields", "Buckler", 0.0, 30.0, typeof( IronIngot ), "Iron Ingot", 10, 1044037 );
			AddCraft( typeof( BronzeShield ), "Shields", "Bronze Shield", 0.0, 30.0, typeof( IronIngot ), "Iron Ingot", 12, 1044037 );
			AddCraft( typeof( MetalShield ), "Shields", "Metal Shield", 0.0, 30.0, typeof( IronIngot ), "Iron Ingot", 14, 1044037 );
			AddCraft( typeof( WoodenKiteShield ), "Shields", "Wooden Kite Shield", 0.0, 30.0, typeof( IronIngot ), "Iron Ingot", 8, 1044037 );
			AddCraft( typeof( MetalKiteShield ), "Shields", "Metal Kite Shield", 0.0, 30.0, typeof( IronIngot ), "Iron Ingot", 16, 1044037 );
			AddCraft( typeof( HeaterShield ), "Shields", "Heater Shield", 24.3, 65.0, typeof( IronIngot ), "Iron Ingot", 18, 1044037 );
			
			// Set the overidable material
			SetSubRes( typeof( IronIngot ), "Iron Ingot" );

			// Add every material you want the player to be able to chose from
			// This will overide the overidable material
			AddSubRes( typeof( IronIngot ), "Iron Ingot", 1.0 );
			AddSubRes( typeof( DullCopperIngot ), "Dull Copper Ingot", 1.1 );
			AddSubRes( typeof( ShadowIronIngot ), "Shadow Iron Ingot", 1.2 );
			AddSubRes( typeof( CopperIngot ), "Copper Ingot", 1.3 );
			AddSubRes( typeof( BronzeIngot ), "Bronze Ingot", 1.4 );
			AddSubRes( typeof( GoldIngot ), "Gold Ingot", 1.5 );
			AddSubRes( typeof( AgapiteIngot ), "Agapite Ingot", 1.6 );
			AddSubRes( typeof( VeriteIngot ), "Verite Ingot", 1.7 );
			AddSubRes( typeof( ValoriteIngot ), "Valorite Ingot", 1.8 );

			Resmelt = true;
		}
	}

	public class ForgeAttribute : Attribute
	{
		public ForgeAttribute()
		{
		}
	}

	public class AnvilAttribute : Attribute
	{
		public AnvilAttribute()
		{
		}
	}
}