using System;
using Server;
using Server.Multis;
using Server.Network;

namespace Server.Items
{
	[FlipableAttribute( 0xe80, 0x9a8 )]
	public class StrongBox : Container
	{
		private Mobile m_Owner;
		private BaseHouse m_House;
		
		public StrongBox( Mobile owner, BaseHouse house ) : base( 0xE80, 0x4B, 0x42, new Rectangle2D( 16, 51, 168, 73 ) )
		{
			m_Owner = owner;
			m_House = house;

			MaxItems = 25;
		}

		[CommandProperty( AccessLevel.GameMaster )]
		public Mobile Owner
		{
			get
			{
				return m_Owner;
			}
			set
			{
				m_Owner = value;
			}
		}

		public override int MaxWeight
		{
			get
			{
				return 0;
			}
		}

		public StrongBox( Serial serial ) : base(serial)
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version

			writer.Write( m_Owner );
			writer.Write( m_House );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();

			switch ( version )
			{
				case 0:
				{
					m_Owner = reader.ReadMobile();
					m_House = reader.ReadItem() as BaseHouse;

					break;
				}
			}
		}

		public override bool Decays
		{
			get
			{
				if ( m_House != null && m_Owner != null && !m_Owner.Deleted )
					return !m_House.IsCoOwner( m_Owner );
				else
					return true;
			}
		}

		public override TimeSpan DecayTime
		{
			get
			{
				return TimeSpan.FromMinutes( 30.0 );
			}
		}

		public override void OnSingleClick( Mobile from )
		{
			if ( m_Owner != null )
			{
				LabelTo( from, 1042887, m_Owner.Name ); // a strong box owned by ~1_OWNER_NAME~

				if ( CheckContentDisplay( from ) )
					LabelTo( from, "({0} items, {1} stones)", TotalItems, TotalWeight );
			}
			else
			{
				base.OnSingleClick( from );
			}
		}

		public override bool IsAccessibleTo( Mobile m )
		{
			if ( m_Owner == null || m_Owner.Deleted || m_House == null || m_House.Deleted )
				return true;

			return ( m.AccessLevel >= AccessLevel.GameMaster || m_House.Owner == m || m_House.CoOwners.Contains( m ) ) && base.IsAccessibleTo( m );
		}
	}
}
