using System;
using Server;
using Server.Network;
using Server.Engines.Craft;

namespace Server.Items
{
	public abstract class BaseTool : Item
	{
		private int m_Durability;

		[CommandProperty( AccessLevel.GameMaster )]
		public int Durability
		{
			set { m_Durability = value; }
			get { return m_Durability; }
		}

		public abstract CraftSystem CraftSystem{ get; }

		public BaseTool( int itemID ) : this( 50, itemID )
		{
		}

		public BaseTool( int durability, int itemID ) : base( itemID )
		{
			m_Durability = durability;
		}

		public BaseTool( Serial serial ) : base( serial )
		{
		}

		public override void GetProperties( Mobile from, ObjectPropertyList list )
		{
			base.GetProperties( from, list );

			list.Add( 1060584, m_Durability.ToString() ); // uses remaining: ~1_val~
		}

		public virtual void DisplayDurabilityTo( Mobile m )
		{
			LabelToAffix( m, 1017323, AffixType.Append, ": " + m_Durability.ToString() ); // Durability
		}

		public override void OnSingleClick( Mobile from )
		{
			DisplayDurabilityTo( from );

			base.OnSingleClick( from );
		}

		public override void OnDoubleClick( Mobile from )
		{
			if ( IsChildOf( from.Backpack ) || Parent == from )
			{
				CraftSystem system = this.CraftSystem;

				if ( system.CanCraft( from, this, null ) )
					from.SendGump( new CraftGump( from, system, this ) );
			}
			else
			{
				from.SendLocalizedMessage( 1042001 ); // That must be in your pack for you to use it.
			}
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version

			writer.Write( (int) m_Durability );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();

			switch ( version )
			{
				case 0:
				{
					m_Durability = reader.ReadInt();
					break;
				}
			}
		}
	}
}