using System;
using Server;
using Server.Mobiles;

namespace Server.Items
{
	public class SlayerGroup
	{
		private static SlayerEntry[] m_TotalEntries;

		public static SlayerEntry GetEntryByName( SlayerName name )
		{
			int v = (int)name;

			if ( v >= 0 && v < m_TotalEntries.Length )
				return m_TotalEntries[v];

			return null;
		}

		static SlayerGroup()
		{
			SlayerGroup humanoid = new SlayerGroup();
			SlayerGroup undead = new SlayerGroup();
			SlayerGroup elemental = new SlayerGroup();
			SlayerGroup abyss = new SlayerGroup();
			SlayerGroup arachnid = new SlayerGroup();
			SlayerGroup reptilian = new SlayerGroup();

			humanoid.Opposition = undead;
			humanoid.Super = new SlayerEntry( SlayerName.Repond, typeof( Ogre ), typeof( Orc ), typeof( OrcishMage ), typeof( OrcishLord ), typeof( Troll ), typeof( Cyclops ), typeof( Titan ), typeof( OrcBrute ), typeof( OrcBomber ), typeof( OrcCaptain ) );
			humanoid.Entries = new SlayerEntry[]
				{
					new SlayerEntry( SlayerName.OgreTrashing, typeof( Ogre ) ),
					new SlayerEntry( SlayerName.OrcSlaying, typeof( Orc ), typeof( OrcishMage ), typeof( OrcishLord ), typeof( OrcBrute ), typeof( OrcBomber ), typeof( OrcCaptain ) ),
					new SlayerEntry( SlayerName.TrollSlaughter, typeof( Troll ) )
				};

			undead.Opposition = humanoid;
			undead.Super = new SlayerEntry( SlayerName.Silver, typeof( AncientLich ), typeof( Bogle ), typeof( BoneMagi ), typeof( Lich ), typeof( LichLord ), typeof( Shade ), typeof( Spectre ), typeof( Wraith ), typeof( BoneKnight ), typeof( Ghoul ), typeof( Mummy ), typeof( SkeletalKnight ), typeof( Skeleton ), typeof( Zombie ) );
			undead.Entries = new SlayerEntry[0];

			elemental.Opposition = abyss;
			elemental.Super = new SlayerEntry( SlayerName.ElementalBan, typeof( BloodElemental ), typeof( EarthElemental ), typeof( PoisonElemental ), typeof( FireElemental ), typeof( SnowElemental ), typeof( AirElemental ), typeof( WaterElemental ) );
			elemental.Entries = new SlayerEntry[]
				{
					new SlayerEntry( SlayerName.BloodDrinking, typeof( BloodElemental ) ),
					new SlayerEntry( SlayerName.EarthShatter, typeof( EarthElemental ) ),
					new SlayerEntry( SlayerName.ElementalHealth, typeof( PoisonElemental ) ),
					new SlayerEntry( SlayerName.FlameDousing, typeof( FireElemental ) ),
					new SlayerEntry( SlayerName.SummerWind, typeof( SnowElemental ) ),
					new SlayerEntry( SlayerName.Vacuum, typeof( AirElemental ) ),
					new SlayerEntry( SlayerName.WaterDissipation, typeof( WaterElemental ) )
				};

			abyss.Opposition = elemental;
			abyss.Super = new SlayerEntry( SlayerName.Exorcism, typeof( Daemon ), typeof( Gargoyle ), typeof( StoneGargoyle ), typeof( FireGargoyle ) ); // No balron?
			abyss.Entries = new SlayerEntry[]
				{
					new SlayerEntry( SlayerName.DaemonDismissal, typeof( Daemon ) ),
					new SlayerEntry( SlayerName.GargoylesFoe, typeof( Gargoyle ), typeof( StoneGargoyle ), typeof( FireGargoyle ) ),
					new SlayerEntry( SlayerName.BalronDamnation, typeof( Balron ) )
				};

			arachnid.Opposition = reptilian;
			arachnid.Super = new SlayerEntry( SlayerName.ArachnidDoom, typeof( GiantSpider ), typeof( TerathanAvenger ), typeof( TerathanDrone ), typeof( TerathanMatriarch ), typeof( TerathanWarrior ) ); // No scorpion?
			arachnid.Entries = new SlayerEntry[]
				{
					new SlayerEntry( SlayerName.ScorpionsBane, typeof( Scorpion ) ),
					new SlayerEntry( SlayerName.SpidersDeath, typeof( GiantSpider ), typeof( TerathanAvenger ), typeof( TerathanDrone ), typeof( TerathanMatriarch ), typeof( TerathanWarrior ) )
				};

			reptilian.Opposition = arachnid;
			reptilian.Super = new SlayerEntry( SlayerName.ReptilianDeath, typeof( Alligator ), typeof( Snake ), typeof( Serpant ), typeof( Silverserpant ), typeof( Lizardman ), typeof( Dragon ), typeof( Drake ), typeof( WhiteWyrm ), typeof( AncientWyrm ), typeof( OphidianAvenger ), typeof( OphidianEnforcer ), typeof( OphidianJusticar ), typeof( OphidianKnight ), typeof( OphidianMage ), typeof( OphidianMatriarch ), typeof( OphidianShaman ), typeof( OphidianWarrior ), typeof( OphidianZealot ) );
			reptilian.Entries = new SlayerEntry[]
				{
					new SlayerEntry( SlayerName.DragonSlaying, typeof( Dragon ) ),
					new SlayerEntry( SlayerName.LizardmanSlaughter, typeof( Lizardman ) ),
					new SlayerEntry( SlayerName.SnakesBane, typeof( Snake ), typeof( Serpant ), typeof( Silverserpant ) )
				};

			m_TotalEntries = CompileEntries( new SlayerGroup[]
				{
					humanoid,
					undead,
					elemental,
					abyss,
					arachnid,
					reptilian
				} );
		}

		private static SlayerEntry[] CompileEntries( SlayerGroup[] groups )
		{
			SlayerEntry[] entries = new SlayerEntry[27];

			for ( int i = 0; i < groups.Length; ++i )
			{
				SlayerGroup g = groups[i];

				g.Super.Group = g;

				entries[(int)g.Super.Name] = g.Super;

				for ( int j = 0; j < g.Entries.Length; ++j )
				{
					g.Entries[j].Group = g;
					entries[(int)g.Entries[j].Name] = g.Entries[j];
				}
			}

			return entries;
		}

		private SlayerGroup m_Opposition;
		private SlayerEntry m_Super;
		private SlayerEntry[] m_Entries;

		public SlayerGroup Opposition{ get{ return m_Opposition; } set{ m_Opposition = value; } }
		public SlayerEntry Super{ get{ return m_Super; } set{ m_Super = value; } }
		public SlayerEntry[] Entries{ get{ return m_Entries; } set{ m_Entries = value; } }

		public SlayerGroup()
		{
		}
	}
}