using System;
using Server.Mobiles;
using Server.Items;

namespace Server.Mobiles
{
	[CorpseName("a horse corpse")]
	public class PackHorse : BaseCreature
	{
		[Constructable]
		public PackHorse() : base( AIType.AI_Animal, FightMode.None, 10, 1, 0.2, 0.4 )
		{
			Body = 291;
			Name = "a pack horse";
			VirtualArmor = 16;

			SetStr( 55, 80 );
			SetDex( 85, 105 );
			SetInt( 15, 30 );

			this.Skills[SkillName.Wrestling].Base = Utility.Random(22,7);
			this.Skills[SkillName.Tactics].Base = Utility.Random(20,9);
			this.Skills[SkillName.MagicResist].Base = Utility.Random(16,5);

			this.Fame = Utility.Random(0,1249);
			this.Karma = Utility.Random(0,-624);

			ControlSlots = 1;
			Tamable = true;

			MinTameSkill = 35.1;// Skill 1st
			MaxTameSkill = 59.1;// Skill 5th

			Container pack = Backpack;

			if ( pack != null )
				pack.Delete();

			pack = new StrongBackpack();
			pack.Movable = false;

			AddItem( pack );
		}

		public override int Meat{ get{ return 3; } }
		public override int Hides{ get{ return 10; } }

		public override bool IsSnoop( Mobile from )
		{
			if ( Controled && from == ControlMaster )
				return false;

			return base.IsSnoop( from );
		}

		public PackHorse(Serial serial) : base(serial)
		{
		}

		public override int GetAttackSound() 
		{ 
			return 0xB7; 
		} 

		public override int GetHurtSound() 
		{ 
			return 0xB8; 
		} 

		public override int GetDeathSound() 
		{ 
			return 0xB9; 
		}

		public override bool OnDragDrop( Mobile from, Item item )
		{
			if ( CheckFeed( from, item ) )
				return true;

			if ( Controled && ControlMaster == from )
			{
				AddToBackpack( item );
				return true;
			}

			return base.OnDragDrop( from, item );
		}

		public override bool CheckNonlocalDrop( Mobile from, Item item, Item target )
		{
			return ( Controled && from == ControlMaster );
		}

		public override bool CheckNonlocalLift( Mobile from, Item item )
		{
			return ( Controled && from == ControlMaster );
		}

		public override void OnDoubleClick( Mobile from )
		{
			Container item = Backpack;

			if ( item == null )
				return;

			object root = item.RootParent;

			if ( !from.CanSee( item ) )
			{
				item.OnDoubleClickCantSee( from );
			}
			else if ( !item.IsAccessibleTo( from ) )
			{
				item.OnDoubleClickNotAccessible( from );
			}
			else if ( !from.CheckAlive( false ) )
			{
				item.OnDoubleClickDead( from );
			}
			else if ( item.InSecureTrade )
			{
				item.OnDoubleClickSecureTrade( from );
			}
			else if ( !item.CheckItemUse( from, item ) )
			{
			}
			else if ( !Controled || from != ControlMaster )
			{
				item.OnSnoop( from );
			}
			else if ( from.Region.OnDoubleClick( from, item ) )
			{
				if ( !item.Deleted )
					item.OnItemUsed( from, item );

				if ( !item.Deleted )
					item.OnDoubleClick( from );
			}
		}

		public override void Serialize(GenericWriter writer)
		{
			base.Serialize(writer);

			writer.Write((int) 0);
		}

		public override void Deserialize(GenericReader reader)
		{
			base.Deserialize(reader);

			int version = reader.ReadInt();
		}
	}
}