using System;
using Server;
using Server.Items;
using Server.GenerateRandomMagicItems;

namespace Server.Mobiles
{
	[CorpseName( "a daemon corpse" )]
	public class Daemon : BaseCreature
	{
		[Constructable]
		public Daemon () : base( AIType.AI_Mage, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Body = 9;
			Name = "a daemon";
			BaseSoundID = 357;

			ControlSlots = 5;

			SetStr( 478, 505 );
			SetDex( 82, 94 );
			SetInt( 305, 325 );
			SetSkill( SkillName.Wrestling, 64, 80 );
			SetSkill( SkillName.Tactics, 70, 79 );
			SetSkill( SkillName.MagicResist, 86, 95 );
			SetSkill( SkillName.Magery, 75, 82 );

			VirtualArmor = Utility.RandomMinMax( 52, 58 );
			SetFameLevel( 5 );
			SetKarmaLevel( 5 );
			

			PackItem( new Gold( 400, 800 ));
			PackItem( RandomScroll.CreateScroll( 1, 7 ) );
			PackItem( RandomScroll.CreateScroll( 1, 7 ) );
			
			// 70% chance to get magic weapons and armor
			if ( 0.7 >= Utility.RandomDouble() ) 
			{
				PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 1, 5 ));
				PackItem( RandomMagicItem.RandomMagicArmor( (BaseArmor)RandomMagicItem.RandomArmor, 1, 5 ));
			}

			// 30% chance to get magic armor, then about 15% chance to get magic weapon
			if ( 0.3 >= Utility.RandomDouble() ) 
			{
				if ( 0.75 >= Utility.RandomDouble() )
				{
					PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 1, 5 ));
				}
				PackItem( RandomMagicItem.RandomMagicArmor( (BaseArmor)RandomMagicItem.RandomArmor, 1, 5 ));
			}
		}

		public override int TreasureMapLevel{ get{ return 4; } }
		public override int Meat{ get{ return 1; } }

		public Daemon( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}
