using System;
using Server;
using Server.Items;
using Server.GenerateRandomMagicItems;

namespace Server.Mobiles
{
	[CorpseName( "a charred corpse" )]
	public class FireGargoyle : BaseCreature
	{
		private static string[] m_Names = new string[]
			{
				"a blistering gargoyle",
				"a burning gargoyle",
				"a firey gargoyle",
				"a flaming gargoyle",
				"a scalding gargoyle",
				"a scorching gargoyle",
				"a searing gargoyle",
				"a smoldering gargoyle",
				"a sweltering gargoyle"
			};

		[Constructable]
		public FireGargoyle() : base( AIType.AI_Mage, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Body = 130;
			Name = m_Names[Utility.Random( m_Names.Length )];
			BaseSoundID = 0x174;

			SetStr( 352, 394 );
			SetDex( 127, 146 );
			SetInt( 226, 250 );
			SetSkill( SkillName.Wrestling, 46, 79 );
			SetSkill( SkillName.Tactics, 83, 99 );
			SetSkill( SkillName.MagicResist, 91, 105 );
			SetSkill( SkillName.Anatomy, 75, 85 );
			SetSkill( SkillName.Magery, 92, 105 );

			VirtualArmor = 32;
			SetFameLevel( 3 );
			SetKarmaLevel( 3 );

			PackGem();

			PackItem( new Gold( 200, 300 ));

			// 30% chance to get magic armor, then about 15% chance to get magic weapon
			if ( 0.3 >= Utility.RandomDouble() ) 
			{
				if ( 0.75 >= Utility.RandomDouble() )
				{
					PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 1, 5 ));
				}
				PackItem( RandomMagicItem.RandomMagicArmor( (BaseArmor)RandomMagicItem.RandomArmor, 1, 5 ));
			}
		}

		public override int TreasureMapLevel{ get{ return 1; } }

		public FireGargoyle( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}