using System;
using Server;
using Server.Items;
using Server.GenerateRandomMagicItems;

namespace Server.Mobiles
{
	[CorpseName( "a gargoyle corpse" )]
	public class Gargoyle : BaseCreature
	{
		[Constructable]
		public Gargoyle() : base( AIType.AI_Mage, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Body = 4;
			Name = "a gargoyle";
			BaseSoundID = 372;

			SetStr( 159, 175 );
			SetDex( 77, 94 );
			SetInt( 82, 100 );
			SetSkill( SkillName.Wrestling, 53, 79 );
			SetSkill( SkillName.Tactics, 50, 69 );
			SetSkill( SkillName.MagicResist, 71, 84 );
			SetSkill( SkillName.Magery, 75, 86 );

			VirtualArmor = 32;
			SetFameLevel( 3 );
			SetKarmaLevel( 3 );

			PackGem();

			PackItem( new Arrow( 10 ));
			PackItem( new Gold( 50, 150 ));
			PackItem( RandomScroll.CreateScroll( 1, 7 ) );
			PackItem( RandomScroll.CreateScroll( 1, 7 ) );

			// 30% chance to get magic armor, then about 15% chance to get magic weapon
			if ( 0.3 >= Utility.RandomDouble() ) 
			{
				if ( 0.75 >= Utility.RandomDouble() )
				{
					PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 1, 5 ));
				}
				PackItem( RandomMagicItem.RandomMagicArmor( (BaseArmor)RandomMagicItem.RandomArmor, 1, 5 ));
			}
		}

		public override int TreasureMapLevel{ get{ return 1; } }

		public Gargoyle( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}