using System;
using System.Collections;
using Server.Items;
using Server.Targeting;
using Server.GenerateRandomMagicItems;
using Server.Misc;

namespace Server.Mobiles
{
	[CorpseName( "an orcish corpse" )]
	public class OrcBrute : BaseCreature
	{
		[Constructable]
		public OrcBrute() : base( AIType.AI_Melee, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Body = 189;
			Name = "an orc brute";
			BaseSoundID = 0x45A;

			SetStr( 854, 883 );
			SetDex( 69, 72 );
			SetInt( 61, 62 );
			SetSkill( SkillName.Wrestling, 97.6, 98 );
			SetSkill( SkillName.Tactics, 93.4, 94.9 );
			SetSkill( SkillName.MagicResist, 137.4, 139.9 );

			VirtualArmor = 50;
			SetFameLevel( 5 );
			SetKarmaLevel( 5 );

			PackItem( new Gold( 50, 350 ) );
			PackItem( new ShadowIronOre( 25 ) );
			PackItem( new IronIngot( 10 ) );

			BaseWeapon weapon = (BaseWeapon)RandomMagicItem.RandomMagicWeapon( new WarMace(), 3, 5 );

			weapon.Quality = WeaponQuality.Regular;

			AddItem( weapon );

			PackItem( RandomMagicItem.RandomMagicArmor( (BaseArmor)RandomMagicItem.RandomArmor, 3, 5 ) );
		}

		public override void OnGotMeleeAttack( Mobile attacker )
		{
			if ( attacker is BaseCreature && ((BaseCreature)attacker).Summoned )
				Dispel( attacker );

			base.OnGotMeleeAttack( attacker );
		}

		public override void AlterDamageScalarFrom( Mobile caster, ref double scalar )
		{
			base.AlterDamageScalarFrom( caster, ref scalar );

			if ( caster is BaseCreature && ((BaseCreature)caster).Summoned )
				Dispel( caster );
			else
				SpawnOrcLord( caster );
		}

		public void SpawnOrcLord( Mobile target )
		{
			Map map = target.Map;

			if ( map == null )
				return;

			IPooledEnumerable eable = map.GetMobilesInRange( this.Location, 10 );
			int orcs = 0;

			foreach ( Mobile m in eable )
			{
				if ( m is OrcishLord )
					++orcs;
			}

			eable.Free();

			if ( orcs < 10 )
			{
				BaseCreature orc = new OrcishLord();

				orc.Team = this.Team;
				orc.Map = map;

				bool validLocation = false;

				for ( int j = 0; !validLocation && j < 10; ++j )
				{
					int x = target.X + Utility.Random( 3 ) - 1;
					int y = target.Y + Utility.Random( 3 ) - 1;
					int z = map.GetAverageZ( x, y );

					if ( validLocation = map.CanFit( x, y, this.Z, 16, false, false ) )
						orc.Location = new Point3D( x, y, Z );
					else if ( validLocation = map.CanFit( x, y, z, 16, false, false ) )
						orc.Location = new Point3D( x, y, z );
				}

				if ( !validLocation )
					orc.Location = target.Location;

				orc.Combatant = target;
			}
		}

		public void Dispel( Mobile m )
		{
			Effects.SendLocationParticles( EffectItem.Create( m.Location, m.Map, TimeSpan.FromSeconds( 5.0 ) ), 0x3728, 8, 20, 5042 );
			Effects.PlaySound( m, m.Map, 0x201 );

			m.Delete();
		}

		public OrcBrute( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}
