using System;
using System.Collections;
using Server.Items;
using Server.Targeting;
using Server.GenerateRandomMagicItems;

namespace Server.Mobiles
{
	[CorpseName( "a gargoyle corpse" )]
	public class StoneGargoyle : BaseCreature
	{
		[Constructable]
		public StoneGargoyle() : base( AIType.AI_Melee, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Body = 67;
			Name = "a stone gargoyle";
			BaseSoundID = 0x174;

			SetStr( 249, 275 );
			SetDex( 82, 94 );
			SetInt( 85, 105 );
			SetSkill( SkillName.Wrestling, 65, 100 );
			SetSkill( SkillName.Tactics, 84, 98 );
			SetSkill( SkillName.MagicResist, 85, 98 );

			VirtualArmor = 50;
			SetFameLevel( 3 );
			SetKarmaLevel( 3 );

			PackGem();

			switch ( Utility.Random( 6 ))
			{
				case 0: PackItem( new AgilityPotion() ); break;
				case 1: PackItem( new LesserCurePotion() ); break;
				case 2: PackItem( new LesserHealPotion() ); break;
				case 3: PackItem( new LesserPoisonPotion() ); break;
				case 4: PackItem( new RefreshPotion() ); break;
				case 5: PackItem( new StrengthPotion() ); break;
			}

			PackItem( new Arrow(10));
			PackItem( new Gold( 150, 250 ));
			PackItem( RandomScroll.CreateScroll( 1, 5 ) );

			// 30% chance to get magic armor, then about 15% chance to get magic weapon
			if ( 0.3 >= Utility.RandomDouble() ) 
			{
				if ( 0.75 >= Utility.RandomDouble() )
				{
					PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 1, 5 ));
				}
				PackItem( RandomMagicItem.RandomMagicArmor( (BaseArmor)RandomMagicItem.RandomArmor, 1, 5 ));
			}
		}

		public override int TreasureMapLevel{ get{ return 2; } }

		public StoneGargoyle( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}