using System;
using Server;
using Server.Items;
using Server.GenerateRandomMagicItems;

namespace Server.Mobiles
{
	[CorpseName( "an ancient wyrm corpse" )]
	public class AncientWyrm : BaseCreature
	{
		[Constructable]
		public AncientWyrm () : base( AIType.AI_Mage, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Body = 798;
			Name = "an ancient wyrm";
			BaseSoundID = 362;

			ControlSlots = 3;

			SetStr( 1103, 1131 );
			SetDex( 99, 120 );
			SetInt( 734, 752 );
			SetSkill( SkillName.Wrestling, 98, 99 );
			SetSkill( SkillName.Tactics, 99, 99 );
			SetSkill( SkillName.MagicResist, 120, 133 );
			SetSkill( SkillName.Magery, 85, 99 );
			SetSkill( SkillName.EvalInt, 72, 78 );
			SetSkill( SkillName.Meditation, 61, 64 );

			VirtualArmor = 70;
			SetFameLevel( 5 );
			SetKarmaLevel( 5 );

			PackGem();
			PackGem();

			switch ( Utility.Random( 6 ))
			{
				case 0: PackItem( new AgilityPotion() ); break;
				case 1: PackItem( new LesserCurePotion() ); break;
				case 2: PackItem( new LesserHealPotion() ); break;
				case 3: PackItem( new LesserPoisonPotion() ); break;
				case 4: PackItem( new RefreshPotion() ); break;
				case 5: PackItem( new StrengthPotion() ); break;
			}

			PackItem( new Gold( 1100, 1300 ));
			PackItem( RandomScroll.CreateScroll( 2, 8 ) );

			// 95% chance to get magic armor, then about 95% chance to get magic weapon
			if ( 0.95 >= Utility.RandomDouble() ) 
			{
				if ( 0.85 >= Utility.RandomDouble() )
				{
					PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 3, 5 ));
				}
				PackItem( RandomMagicItem.RandomMagicArmor( (BaseArmor)RandomMagicItem.RandomArmor, 3, 5 ));
			}
			// 80% chance to get magic armor, then about 65% chance to get magic weapon
			if ( 0.8 >= Utility.RandomDouble() ) 
			{
				if ( 0.75 >= Utility.RandomDouble() )
				{
					PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 4, 5 ));
				}
				PackItem( RandomMagicItem.RandomMagicArmor( (BaseArmor)RandomMagicItem.RandomArmor, 4, 5 ));
			}
			// 80% chance to get magic armor, then about 65% chance to get magic weapon
			if ( 0.8 >= Utility.RandomDouble() ) 
			{
				if ( 0.75 >= Utility.RandomDouble() )
				{
					PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 4, 5 ));
				}
				PackItem( RandomMagicItem.RandomMagicArmor( (BaseArmor)RandomMagicItem.RandomArmor, 4, 5 ));
			}
		}

		public override int TreasureMapLevel{ get{ return 5; } }

		public AncientWyrm( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}