using System;
using Server;
using Server.Items;
using Server.GenerateRandomMagicItems;

namespace Server.Mobiles
{
	[CorpseName( "a skeletal dragon corpse" )]
	public class SkeletalDragon : BaseCreature
	{
		[Constructable]
		public SkeletalDragon () : base( AIType.AI_Mage, FightMode.Closest, 10, 1, 0.2, 0.4 )
		{
			Body = 104;
			Name = "a skeletal dragon";
			BaseSoundID = 362;

			ControlSlots = 3;

			SetStr( 932, 960 );
			SetDex( 130, 132 );
			SetInt( 528, 572 );
			SetSkill( SkillName.Wrestling, 98, 99 );
			SetSkill( SkillName.Tactics, 98, 98 );
			SetSkill( SkillName.MagicResist, 117, 120 );
			SetSkill( SkillName.Magery, 89, 99 );
			SetSkill( SkillName.EvalInt, 72, 76 );
			SetSkill( SkillName.Meditation, 62, 63 );

			VirtualArmor = 80;
			SetFameLevel( 5 );
			SetKarmaLevel( 5 );

			PackGem();
			PackGem();

			PackItem( new Gold( 2000, 3000 ));
			PackItem( RandomScroll.CreateScroll( 4, 8 ) );
			PackItem( RandomScroll.CreateScroll( 4, 8 ) );

			// 70% chance to get magic armor, then about 55% chance to get magic weapon
			if ( 0.7 >= Utility.RandomDouble() ) 
			{
				if ( 0.75 >= Utility.RandomDouble() )
				{
					PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 1, 5 ));
				}
				PackItem( RandomMagicItem.RandomMagicArmor( (BaseArmor)RandomMagicItem.RandomArmor, 1, 5 ));
			}
		}

		public override int Hides{ get{ return 20; } }
		public override HideType HideType{ get{ return HideType.Barbed; } }

		public SkeletalDragon( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}