using System;
using System.Collections;
using Server.Items;
using Server.GenerateRandomMagicItems;
using Server.Engines.CannedEvil;

namespace Server.Mobiles
{
	public class Semidar : BaseChampion
	{
		public override ChampionSkullType SkullType{ get{ return ChampionSkullType.Pain; } }

		[Constructable]
		public Semidar() : base( AIType.AI_Mage )
		{
			Body = 174;
			Name = "Semidar";
			BaseSoundID = 0x4B0;

			SetFameLevel( 5 );
			SetKarmaLevel( 5 );

			SetStr( 575, 575 );
			SetDex( 175, 175 );
			SetInt( 730, 730 );

			VirtualArmor = 20;

			SetSkill( SkillName.Wrestling, 102.1, 102.1 );
			SetSkill( SkillName.Tactics, 94.4, 94.4 );
			SetSkill( SkillName.MagicResist, 129.2, 129.2 );
			SetSkill( SkillName.Magery, 91.5, 91.5 );
			SetSkill( SkillName.EvalInt, 99.4, 99.4 );
			SetSkill( SkillName.Meditation, 98.3, 98.3 );

			PackItem( new Gold( 6000, 6500 ));

			PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 3, 5 ) );
			PackItem( RandomMagicItem.RandomMagicWeapon( (BaseWeapon)RandomMagicItem.RandomWeapon, 5, 5 ) );
		}

		[CommandProperty( AccessLevel.GameMaster )]
		public override int HitsMax{ get{ return 2500; } }

		public override void CheckReflect( Mobile caster, ref bool reflect )
		{
			if ( caster.Body.IsMale )
				reflect = true; // Always reflect if caster isn't female
		}

		public override void AlterDamageScalarFrom( Mobile caster, ref double scalar )
		{
			if ( caster.Body.IsMale )
				scalar = 20; // Male bodies always reflect.. damage scaled 20x
		}

		public void DrainLife()
		{
			Map map = this.Map;

			if ( map == null )
				return;

			IPooledEnumerable eable = map.GetMobilesInRange( this.Location, 2 );
			ArrayList list = new ArrayList();

			foreach ( Mobile m in eable )
			{
				if ( m == this || !CanBeHarmful( m ) )
					continue;

				if ( m is BaseCreature && (((BaseCreature)m).Controled || ((BaseCreature)m).Summoned || ((BaseCreature)m).Team != this.Team) )
					list.Add( m );
				else if ( m.Player )
					list.Add( m );
			}

			eable.Free();

			foreach ( Mobile m in list )
			{
				DoHarmful( m );

				Effects.SendTargetParticles( m, 0x374A, 10, 15, 0x496, 0, 5013, EffectLayer.Waist, 0 );
				m.PlaySound( 0x231 );
				m.SendMessage( "You feel the life drain out of you!" );

				int toDrain = Utility.RandomMinMax( 10, 40 );

				Hits += toDrain;
				m.Damage( toDrain );
			}
		}

		public override void OnGaveMeleeAttack( Mobile defender )
		{
			if ( 0.25 >= Utility.RandomDouble() )
				DrainLife();
		}

		public override void OnGotMeleeAttack( Mobile attacker )
		{
			if ( 0.25 >= Utility.RandomDouble() )
				DrainLife();
		}

		public Semidar( Serial serial ) : base( serial )
		{
		}

		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );
			writer.Write( (int) 0 );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );
			int version = reader.ReadInt();
		}
	}
}
