using System;
using Server.Targeting;
using Server.Network;
using Server.Mobiles;
using Server.Items;

namespace Server.SkillHandlers
{
	public class Provocation
	{
		public static void Initialize()
		{
			SkillInfo.Table[(int)SkillName.Provocation].Callback = new SkillUseCallback( OnUse );
		}

		public static TimeSpan OnUse( Mobile m )
		{
			m.RevealingAction();

			BaseInstrument instrument = BaseInstrument.GetInstrument( m );

			if ( instrument == null )
			{
				m.Target = new InternalMusicTarget();
				m.SendLocalizedMessage( 500617 ); // What instrument shall you play?
			}
			else
			{
				m.SendMessage( "Select the creature to provoke" );
				m.Target = new InternalFirstTarget( instrument );
			}

			return TimeSpan.FromSeconds( 10.0 ); // 10 second delay before beign able to re-use a skill
		}

		private class InternalMusicTarget : Target
		{
			public InternalMusicTarget() : base ( 1, false, TargetFlags.None )
			{
			}

			protected override void OnTarget( Mobile from, object targeted )
			{
				if ( targeted is BaseInstrument )
				{
					BaseInstrument.SetInstrument( from, (BaseInstrument)targeted );

					// Can't find the localized message
					from.SendMessage( "Select the creature to provoke" );
					from.Target = new InternalFirstTarget( (BaseInstrument)targeted );
				}
				else
				{
					from.SendLocalizedMessage( 500619 ); // That is not a musical instrument.
				}
			}
		}

		private class InternalFirstTarget : Target
		{
			private BaseInstrument m_Instrument;

			public InternalFirstTarget( BaseInstrument instrument ) :  base ( 10, false, TargetFlags.None )
			{
				m_Instrument = instrument;
			}

			protected override void OnTarget( Mobile from, object targeted )
			{
				from.RevealingAction();

				if ( targeted is BaseCreature && from.CanBeHarmful( (Mobile)targeted, true ) )
				{
					BaseCreature creature = (BaseCreature)targeted;

					// OSI can reprovoke
					//if ( !creature.BardProvoked )
					//{					
						// Can't find the localized message
						from.SendMessage( "Select the target creature" );
						from.Target = new InternalSecondTarget( m_Instrument, creature );
						from.RevealingAction();
					//}
					//else
					//{
					//	from.SendLocalizedMessage( 1049447 ); // That creature is already being provoked.
					//}
				}
			}
		}

		private class InternalSecondTarget : Target
		{
			private BaseCreature m_Creature;
			private BaseInstrument m_Instrument;

			public InternalSecondTarget( BaseInstrument instrument, BaseCreature creature ) :  base ( 10, false, TargetFlags.None )
			{
				m_Instrument = instrument;
				m_Creature = creature;
			}

			protected override void OnTarget( Mobile from, object targeted )
			{
				from.RevealingAction();

				if ( targeted is BaseCreature )
				{
					BaseCreature creature = (BaseCreature)targeted;

					if ( m_Creature.Map != creature.Map || !m_Creature.InRange( creature, 12 ) )
					{
						from.SendLocalizedMessage( 1049450 ); // The creatures you are trying to provoke are too far away from each other for your music to have an effect.
						return;
					}

					if ( m_Creature != creature )
					{
						double diff = ( BaseInstrument.GetDifficultyFor( m_Creature ) + BaseInstrument.GetDifficultyFor( creature ) ) / 2.0;

						if ( from.CanBeHarmful( m_Creature, true ) && from.CanBeHarmful( creature, true ) )
						{
							from.DoHarmful( m_Creature );
							from.DoHarmful( creature );

							if ( !from.CheckSkill( SkillName.Provocation, diff-25.0, diff+25.0 ) )
							{
								m_Instrument.PlayInstrumentBadly( from );
								from.SendLocalizedMessage( 500612 ); // You play poorly, and there is no effect.
							}
							else
							{
								m_Instrument.PlayInstrumentWell( from );
								m_Creature.Provoke( from, creature, true );
							}
						}
					}
				}
			}
		}
	}
}